==> ReleaseV1.1.0.zip: wingreportservice/ReportService/ReportConverter/ReportPreviewHelper.cs <==
using System.Diagnostics;
using System.Text;
using ReportService.Posters;
using SkiaSharp;
using WingInterfaceLibrary.DTO.Report;
using WingInterfaceLibrary.Enum;
using WingServerCommon.Log;

namespace ReportService.ReportConverter
{
    public class ReportPreviewHelper
    {
        private static readonly string _reportPreviewFolder = Path.Combine(AppDomain.CurrentDomain.BaseDirectory, "ReportPreviewTemp");

        /// <summary>
        /// 生成报告预览图
        /// </summary>
        /// <param name="reportInfo"></param>
        /// <returns></returns>
        public static List<string> GetReportPreviewPath(ReportDTO reportInfo, UploadFileTypeEnum fileType)
        {
            try
            {
                if (!Directory.Exists(_reportPreviewFolder))
                {
                    Directory.CreateDirectory(_reportPreviewFolder);
                }
                else
                {
                    //删除过时文件
                    FileHelper.DeleteFile(_reportPreviewFolder, DateTime.Now.AddDays(-1));
                }
                DirectoryInfo reportFolder = new DirectoryInfo(_reportPreviewFolder);
                string fileName = $"{reportInfo.ReportCode}_{reportInfo.UpdateTime.Ticks}";
                string filePath = Path.Combine(_reportPreviewFolder, fileName);

                var files = reportFolder.GetFiles().Where(f => f.FullName.Contains(fileName) && f.Extension == $".{fileType.ToString().ToLower()}");
                if (files != null && files.Any())
                {
                    foreach (var file in files)
                    {
                        file.Delete();
                    }
                }
                //生成报告json文件
                ReportJsonSerializer.Serialize($"{filePath}.json", reportInfo);

                if (fileType == UploadFileTypeEnum.PDF)
                {
                    string converterParm = $"\"Packaging\" \"{filePath}\" \"zh\" \" \" \" \" \"{1.5f}\"";
                    ConverterReport(converterParm);
                    var pdfFile = filePath + ".pdf";
                    if (File.Exists(pdfFile))
                    {
                        return new List<string> { pdfFile };
                    }
                }
                else
                {
                    //生成报告预览图
                    string converterParm = $"\"Share\" \"{filePath}\" \"zh\" \" \" \" \" \"{1.5f}\"";
                    ConverterReport(converterParm);
                    var imageFiles = Directory.GetFiles(_reportPreviewFolder, $"{fileName}*.jpg", System.IO.SearchOption.TopDirectoryOnly);
                    if (imageFiles == null || !imageFiles.Any())
                    {
                        //生成失败
                        Logger.WriteLineWarn($"report converter failed, report code:{reportInfo.ReportCode}");
                        return new List<string>();
                    }
                    return imageFiles.ToList();
                }
            }
            catch (Exception ex)
            {
                Logger.WriteLineWarn($"GetReportPreviewPath err {ex}");
            }
            return new List<string>();
        }

        /// <summary>
        /// Converter Report
        /// </summary>
        /// <param name="converterParm">ReportConverter.exe param</param>
        private static bool ConverterReport(string converterParm)
        {
            var psi = new ProcessStartInfo(
                Path.Combine(AppDomain.CurrentDomain.BaseDirectory, "Tools", "ReportConverter", "ReportConverter.exe"), converterParm)
            { RedirectStandardOutput = true };
            var process = Process.Start(psi);
            process?.WaitForExit();
            process?.Close();
            return true;
        }

        private static string MergeImages(List<string> files, string reportId)
        {
            var images = new List<SKImage>();
            try
            {
                var totalHeight = 0;
                var maxWidth = 0;
                foreach (var fullName in files)
                {
                    SKImage image = SKImage.FromEncodedData(SKData.Create(fullName));
                    images.Add(image);
                    totalHeight += image.Height;
                    if (maxWidth < image.Width)
                    {
                        maxWidth = image.Width;
                    }
                }
                totalHeight += (files.Count - 1) * 5;

                using (SKBitmap bitmap = new SKBitmap(maxWidth, totalHeight))
                {
                    using (SKCanvas canvas = new SKCanvas(bitmap))
                    {
                        canvas.Clear(SKColor.Empty);
                        var y = 0;
                        foreach (var image in images)
                        {
                            var rect = SKRect.Create(0, y, image.Width, image.Height);
                            canvas.DrawImage(image, rect);
                            y = y + image.Height + 5;
                        }
                    }
                    var filePath = Path.Combine(_reportPreviewFolder, $"{reportId}_{Guid.NewGuid():N}.jpg");
                    using (SKImage img = SKImage.FromBitmap(bitmap))
                    {
                        using (SKData p = img.Encode(SKEncodedImageFormat.Jpeg, 100))
                        {
                            using (var stream = File.Create(filePath))
                            {
                                stream.Write(p.ToArray(), 0, p.ToArray().Length);
                            }
                        }
                    }
                    return filePath;
                }
            }
            catch (Exception ex)
            {
                Logger.WriteLineError($"report preview merge image err,{ex}");
            }
            finally
            {
                foreach (var image in images)
                {
                    image?.Dispose();
                }
            }
            return string.Empty;
        }
    }
}

==> ReleaseV1.1.1.zip: wingreportservice/ReportService/ReportConverter/ReportPreviewHelper.cs <==
using System.Diagnostics;
using System.Text;
using ReportService.Posters;
using SkiaSharp;
using WingInterfaceLibrary.DTO.Report;
using WingInterfaceLibrary.Enum;
using WingServerCommon.Log;

namespace ReportService.ReportConverter
{
    public class ReportPreviewHelper
    {
        private static readonly string _reportPreviewFolder = Path.Combine(AppDomain.CurrentDomain.BaseDirectory, "ReportPreviewTemp");

        /// <summary>
        /// 生成报告预览图
        /// </summary>
        /// <param name="reportInfo"></param>
        /// <returns></returns>
        public static List<string> GetReportPreviewPath(ReportDTO reportInfo, UploadFileTypeEnum fileType)
        {
            try
            {
                if (!Directory.Exists(_reportPreviewFolder))
                {
                    Directory.CreateDirectory(_reportPreviewFolder);
                }
                else
                {
                    //删除过时文件
                    FileHelper.DeleteFile(_reportPreviewFolder, DateTime.Now.AddDays(-1));
                }
                DirectoryInfo reportFolder = new DirectoryInfo(_reportPreviewFolder);
                string fileName = $"{reportInfo.ReportCode}_{reportInfo.UpdateTime.Ticks}";
                string filePath = Path.Combine(_reportPreviewFolder, fileName);

                var files = reportFolder.GetFiles().Where(f => f.FullName.Contains(fileName) && f.Extension == $".{fileType.ToString().ToLower()}");
                if (files != null && files.Any())
                {
                    foreach (var file in files)
                    {
                        file.Delete();
                    }
                }
                //生成报告json文件
                ReportJsonSerializer.Serialize($"{filePath}.json", reportInfo);

                if (fileType == UploadFileTypeEnum.PDF)
                {
                    string converterParm = $"\"Packaging\" \"{filePath}\" \"zh\" \" \" \" \" \"{1.5f}\"";
                    ConverterReport(converterParm);
                    var pdfFile = filePath + ".pdf";
                    if (File.Exists(pdfFile))
                    {
                        return new List<string> { pdfFile };
                    }
                }
                else
                {
                    //生成报告预览图
                    string converterParm = $"\"Share\" \"{filePath}\" \"zh\" \" \" \" \" \"{1.5f}\"";
                    ConverterReport(converterParm);
                    var imageFiles = Directory.GetFiles(_reportPreviewFolder, $"{fileName}*.jpg", System.IO.SearchOption.TopDirectoryOnly);
                    if (imageFiles == null || !imageFiles.Any())
                    {
                        //生成失败
                        Logger.WriteLineWarn($"report converter failed, report code:{reportInfo.ReportCode}");
                        return new List<string>();
                    }
                    return imageFiles.ToList();
                }
            }
            catch (Exception ex)
            {
                Logger.WriteLineWarn($"GetReportPreviewPath err {ex}");
            }
            return new List<string>();
        }

        /// <summary>
        /// Converter Report
        /// </summary>
        /// <param name="converterParm">ReportConverter.exe param</param>
        private static bool ConverterReport(string converterParm)
        {
            var psi = new ProcessStartInfo(
                Path.Combine(AppDomain.CurrentDomain.BaseDirectory, "Packages", "ReportConverter", "ReportConverter.exe"), converterParm)
            { RedirectStandardOutput = true };
            var process = Process.Start(psi);
            process?.WaitForExit();
            process?.Close();
            return true;
        }

        private static string MergeImages(List<string> files, string reportId)
        {
            var images = new List<SKImage>();
            try
            {
                var totalHeight = 0;
                var maxWidth = 0;
                foreach (var fullName in files)
                {
                    SKImage image = SKImage.FromEncodedData(SKData.Create(fullName));
                    images.Add(image);
                    totalHeight += image.Height;
                    if (maxWidth < image.Width)
                    {
                        maxWidth = image.Width;
                    }
                }
                totalHeight += (files.Count - 1) * 5;

                using (SKBitmap bitmap = new SKBitmap(maxWidth, totalHeight))
                {
                    using (SKCanvas canvas = new SKCanvas(bitmap))
                    {
                        canvas.Clear(SKColor.Empty);
                        var y = 0;
                        foreach (var image in images)
                        {
                            var rect = SKRect.Create(0, y, image.Width, image.Height);
                            canvas.DrawImage(image, rect);
                            y = y + image.Height + 5;
                        }
                    }
                    var filePath = Path.Combine(_reportPreviewFolder, $"{reportId}_{Guid.NewGuid():N}.jpg");
                    using (SKImage img = SKImage.FromBitmap(bitmap))
                    {
                        using (SKData p = img.Encode(SKEncodedImageFormat.Jpeg, 100))
                        {
                            using (var stream = File.Create(filePath))
                            {
                                stream.Write(p.ToArray(), 0, p.ToArray().Length);
                            }
                        }
                    }
                    return filePath;
                }
            }
            catch (Exception ex)
            {
                Logger.WriteLineError($"report preview merge image err,{ex}");
            }
            finally
            {
                foreach (var image in images)
                {
                    image?.Dispose();
                }
            }
            return string.Empty;
        }
    }
}
